;**********************************************************************
;* Filename:	pins.inc
;* Project:		EPROM emulator
;* Date:		05 June 2005
;* Version:		0.1
;* Author:		Philip Pemberton
;* 
;* Pin definitions for EPROM emulator.
;**********************************************************************

;**********************************************************************
;** INITIAL TRIS VALUES
;**********************************************************************

porta_tris	equ	B'00000000'		; Initial TRIS state for PORTA
	;			  **------	N/A
	;			  --0-----	RA5		!WRITE
	;			  ---0----	RA4		Not used
	;			  ----0---	RA3		!READ
	;			  -----0--	RA2		AHEN
	;			  ------0-  RA1		!RUN
	;			  -------0	RA0		RESET

portb_tris	equ	B'00000000'		; Initial TRIS state for PORTB
	;			  00000000	RB7-0	D7-D0

portc_tris	equ B'11001000'		; Initial TRIS state for PORTC
	;			  11------	RC7-6	RXD, TXD (UART)
	;			  --0-----	RC5		SELA
	;			  ---0----	RC4		SELB
	;			  ----1---	RC3		CTS
	;			  -----0--	RC2		RTS
	;			  ------00	RC1-0	Unused

portd_tris	equ	B'00000000'		; Initial TRIS state for PORTD
	;			  00000000	RD7-0	A7-A0

porte_tris	equ	B'00000000'		; Initial TRIS state for PORTE
	;			  *****---	N/A
	;			  -----0--	RE3		AHOE
	;			  ------00	RE2-0	Unused (set to output mode)

;**********************************************************************
;** INITIAL PORT STATES
;**********************************************************************

porta_state	equ	B'00101011'		; Initial PORTA state
	;			  **------	N/A
	;			  --1-----	RA5		!WRITE
	;			  ---0----	RA4		Not used
	;			  ----1---	RA3		!READ
	;			  -----0--	RA2		!AHOE
	;			  ------1-  RA1		!RUN
	;			  -------1	RA0		RESET

portb_state	equ	B'00000000'		; Initial PORTB state
	;			  00000000	RB7-0	D7-D0

portc_state	equ	B'11001100'		; Initial PORTC state
	;			  11------	RC7-6	RXD, TXD (UART)
	;			  --0-----	RC5		SELA
	;			  ---0----	RC4		SELB
	;			  ----1---	RC3		CTS
	;			  -----1--	RC2		RTS
	;			  ------00	RC1-0	Unused

portd_state	equ	B'00000000'		; Initial PORTD state
	;			  00000000	RD7-0	A7-A0

porte_state	equ	B'00000000'		; Initial PORTE state
	;			  *****---	N/A
	;			  -----0--	RE3		AHOE
	;			  ------00	RE2-0	Unused

;**********************************************************************
;** PIN DEFINITIONS
;**********************************************************************

;---------------------------------- Port A
; nWRITE:		PORTA, 5
#define	nWRITE_PORT	PORTA
#define	nWRITE_TRIS	TRISA
#define	nWRITE_PIN	5
#define	nWRITE		nWRITE_PORT, nWRITE_PIN

; nREAD:		PORTA,	3
#define	nREAD_PORT	PORTA
#define	nREAD_TRIS	TRISA
#define	nREAD_PIN	3
#define	nREAD		nREAD_PORT, nREAD_PIN

; nAHOE:		PORTA,	2
#define	nAHOE_PORT	PORTA
#define	nAHOE_TRIS	TRISA
#define	nAHOE_PIN	2
#define	nAHOE		nAHOE_PORT, nAHOE_PIN

; nRUN:			PORTA,	1
#define	nRUN_PORT	PORTA
#define	nRUN_TRIS	TRISA
#define	nRUN_PIN	1
#define	nRUN		nRUN_PORT, nRUN_PIN

; RESET:		PORTA,	0
#define	RESET_PORT	PORTA
#define	RESET_TRIS	TRISA
#define	RESET_PIN	0
#define	RESET		RESET_PORT, RESET_PIN

;---------------------------------- Port B
; DATA_PORT:	PORTB
#define	DATA_PORT	PORTB
#define	DATA_TRIS	TRISB

;---------------------------------- Port C
; SELA:			PORTC,	5
#define	SELA_PORT	PORTC
#define	SELA_TRIS	TRISC
#define	SELA_PIN	5
#define	SELA		SELA_PORT, SELA_PIN

; SELB:			PORTC,	4
#define	SELB_PORT	PORTC
#define	SELB_TRIS	TRISC
#define	SELB_PIN	4
#define	SELB		SELB_PORT, SELB_PIN

; CTS:			PORTC,	3
#define	CTS_PORT	PORTC
#define	CTS_TRIS	TRISC
#define	CTS_PIN		3
#define	CTS			CTS_PORT, CTS_PIN

; RTS:			PORTC,	2
#define	RTS_PORT	PORTC
#define	RTS_TRIS	TRISC
#define	RTS_PIN		2
#define	RTS			RTS_PORT, RTS_PIN

;---------------------------------- Port D
; ADRL_PORT:	PORTD
#define	ADRL_PORT	PORTD
#define	ADRL_TRIS	TRISD

;---------------------------------- Port E

; AHEN:			PORTE,	0
#define	AHEN_PORT	PORTE
#define	AHEN_TRIS	TRISE
#define	AHEN_PIN	0
#define	AHEN		AHEN_PORT, AHEN_PIN
